Class: Aws::RDSDataService::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::RDSDataService::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-rdsdataservice/client.rb,
sig/client.rbs
Overview
An API client for RDSDataService. To construct a client, you need to configure a :region and :credentials.
client = Aws::RDSDataService::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _BatchExecuteStatementResponseSuccess, _BeginTransactionResponseSuccess, _CommitTransactionResponseSuccess, _ExecuteSqlResponseSuccess, _ExecuteStatementResponseSuccess, _RollbackTransactionResponseSuccess
Constant Summary collapse
- Params =
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#batch_execute_statement(params = {}) ⇒ Types::BatchExecuteStatementResponse
Runs a batch SQL statement over an array of data.
-
#begin_transaction(params = {}) ⇒ Types::BeginTransactionResponse
Starts a SQL transaction.
-
#commit_transaction(params = {}) ⇒ Types::CommitTransactionResponse
Ends a SQL transaction started with the
BeginTransactionoperation and commits the changes. -
#execute_sql(params = {}) ⇒ Types::ExecuteSqlResponse
Runs one or more SQL statements.
-
#execute_statement(params = {}) ⇒ Types::ExecuteStatementResponse
Runs a SQL statement against a database.
-
#rollback_transaction(params = {}) ⇒ Types::RollbackTransactionResponse
Performs a rollback of a transaction.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-rdsdataservice/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1090 1091 1092 |
# File 'lib/aws-sdk-rdsdataservice/client.rb', line 1090 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1093 1094 1095 |
# File 'lib/aws-sdk-rdsdataservice/client.rb', line 1093 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14 def self.new: ( |
Instance Method Details
#batch_execute_statement(params = {}) ⇒ Types::BatchExecuteStatementResponse
Runs a batch SQL statement over an array of data.
You can run bulk update and insert operations for multiple records using a DML statement with different parameter sets. Bulk operations can provide a significant performance improvement over individual insert and update operations.
transactionID parameter, changes that result from the call are
committed automatically.
There isn't a fixed upper limit on the number of parameter sets. However, the maximum size of the HTTP request submitted through the Data API is 4 MiB. If the request exceeds this limit, the Data API returns an error and doesn't process the request. This 4-MiB limit includes the size of the HTTP headers and the JSON notation in the request. Thus, the number of parameter sets that you can include depends on a combination of factors, such as the size of the SQL statement and the size of each parameter set.
The response size limit is 1 MiB. If the call returns more than 1 MiB of response data, the call is terminated.
86 |
# File 'sig/client.rbs', line 86 def batch_execute_statement: ( |
#begin_transaction(params = {}) ⇒ Types::BeginTransactionResponse
Starts a SQL transaction.
A transaction times out if no calls use its transaction ID in three minutes. If a transaction times out before it's committed, it's rolled back automatically.
For Aurora MySQL, DDL statements inside a transaction cause an
implicit commit. We recommend that you run each MySQL DDL statement in
a separate ExecuteStatement call with continueAfterTimeout
enabled.
106 |
# File 'sig/client.rbs', line 106 def begin_transaction: ( |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1063 1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 1077 1078 1079 |
# File 'lib/aws-sdk-rdsdataservice/client.rb', line 1063 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::RDSDataService') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-rdsdataservice' context[:gem_version] = '1.92.0' Seahorse::Client::Request.new(handlers, context) end |
#commit_transaction(params = {}) ⇒ Types::CommitTransactionResponse
Ends a SQL transaction started with the BeginTransaction operation
and commits the changes.
119 |
# File 'sig/client.rbs', line 119 def commit_transaction: ( |
#execute_sql(params = {}) ⇒ Types::ExecuteSqlResponse
Runs one or more SQL statements.
BatchExecuteStatement
or ExecuteStatement operation.
131 |
# File 'sig/client.rbs', line 131 def execute_sql: ( |
#execute_statement(params = {}) ⇒ Types::ExecuteStatementResponse
Runs a SQL statement against a database.
transactionID parameter, changes that result from the call are
committed automatically.
If the binary response data from the database is more than 1 MB, the call is terminated.
149 |
# File 'sig/client.rbs', line 149 def execute_statement: ( |
#rollback_transaction(params = {}) ⇒ Types::RollbackTransactionResponse
Performs a rollback of a transaction. Rolling back a transaction cancels its changes.
174 |
# File 'sig/client.rbs', line 174 def rollback_transaction: ( |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1083 1084 1085 |
# File 'lib/aws-sdk-rdsdataservice/client.rb', line 1083 def waiter_names [] end |