Module: Aws::RDSDataService::Types
- Defined in:
- lib/aws-sdk-rdsdataservice/types.rb
Defined Under Namespace
Classes: AccessDeniedException, ArrayValue, BadRequestException, BatchExecuteStatementRequest, BatchExecuteStatementResponse, BeginTransactionRequest, BeginTransactionResponse, ColumnMetadata, CommitTransactionRequest, CommitTransactionResponse, DatabaseErrorException, DatabaseNotFoundException, DatabaseResumingException, DatabaseUnavailableException, ExecuteSqlRequest, ExecuteSqlResponse, ExecuteStatementRequest, ExecuteStatementResponse, Field, ForbiddenException, HttpEndpointNotEnabledException, InternalServerErrorException, InvalidResourceStateException, InvalidSecretException, NotFoundException, Record, ResultFrame, ResultSetMetadata, ResultSetOptions, RollbackTransactionRequest, RollbackTransactionResponse, SecretsErrorException, ServiceUnavailableError, SqlParameter, SqlStatementResult, StatementTimeoutException, StructValue, TransactionNotFoundException, UnsupportedResultException, UpdateResult, Value
Instance Attribute Summary collapse
-
#array_value ⇒ Types::ArrayValue
An array of values.
-
#array_values ⇒ Array<Types::Value>
An array of column values.
-
#big_int_value ⇒ Integer
A value for a column of big integer data type.
-
#bit_value ⇒ Boolean
A value for a column of BIT data type.
-
#blob_value ⇒ String
A value for a column of BLOB data type.
-
#boolean_value ⇒ Boolean
A value of Boolean data type.
-
#boolean_values ⇒ Array<Boolean>
An array of Boolean values.
-
#double_value ⇒ Float
A value for a column of double data type.
-
#double_values ⇒ Array<Float>
An array of floating-point numbers.
-
#int_value ⇒ Integer
A value for a column of integer data type.
-
#is_null ⇒ Boolean
A NULL value.
-
#long_value ⇒ Integer
A value of long data type.
-
#long_values ⇒ Array<Integer>
An array of integers.
-
#real_value ⇒ Float
A value for a column of real data type.
-
#string_value ⇒ String
A value for a column of string data type.
-
#string_values ⇒ Array<String>
An array of strings.
-
#struct_value ⇒ Types::StructValue
A value for a column of STRUCT data type.
Instance Attribute Details
#array_value ⇒ Types::ArrayValue
An array of values.
664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 |
# File 'lib/aws-sdk-rdsdataservice/types.rb', line 664 class Field < Struct.new( :is_null, :boolean_value, :long_value, :double_value, :string_value, :blob_value, :array_value, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class IsNull < Field; end class BooleanValue < Field; end class LongValue < Field; end class DoubleValue < Field; end class StringValue < Field; end class BlobValue < Field; end class ArrayValue < Field; end class Unknown < Field; end end |
#array_values ⇒ Array<Types::Value>
An array of column values.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/aws-sdk-rdsdataservice/types.rb', line 54 class ArrayValue < Struct.new( :boolean_values, :long_values, :double_values, :string_values, :array_values, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class BooleanValues < ArrayValue; end class LongValues < ArrayValue; end class DoubleValues < ArrayValue; end class StringValues < ArrayValue; end class ArrayValues < ArrayValue; end class Unknown < ArrayValue; end end |
#big_int_value ⇒ Integer
A value for a column of big integer data type.
1134 1135 1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 1147 1148 1149 1150 1151 1152 1153 1154 1155 1156 1157 1158 1159 1160 1161 |
# File 'lib/aws-sdk-rdsdataservice/types.rb', line 1134 class Value < Struct.new( :is_null, :bit_value, :big_int_value, :int_value, :double_value, :real_value, :string_value, :blob_value, :array_values, :struct_value, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class IsNull < Value; end class BitValue < Value; end class BigIntValue < Value; end class IntValue < Value; end class DoubleValue < Value; end class RealValue < Value; end class StringValue < Value; end class BlobValue < Value; end class ArrayValues < Value; end class StructValue < Value; end class Unknown < Value; end end |
#bit_value ⇒ Boolean
A value for a column of BIT data type.
1134 1135 1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 1147 1148 1149 1150 1151 1152 1153 1154 1155 1156 1157 1158 1159 1160 1161 |
# File 'lib/aws-sdk-rdsdataservice/types.rb', line 1134 class Value < Struct.new( :is_null, :bit_value, :big_int_value, :int_value, :double_value, :real_value, :string_value, :blob_value, :array_values, :struct_value, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class IsNull < Value; end class BitValue < Value; end class BigIntValue < Value; end class IntValue < Value; end class DoubleValue < Value; end class RealValue < Value; end class StringValue < Value; end class BlobValue < Value; end class ArrayValues < Value; end class StructValue < Value; end class Unknown < Value; end end |
#blob_value ⇒ String
A value for a column of BLOB data type.
664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 |
# File 'lib/aws-sdk-rdsdataservice/types.rb', line 664 class Field < Struct.new( :is_null, :boolean_value, :long_value, :double_value, :string_value, :blob_value, :array_value, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class IsNull < Field; end class BooleanValue < Field; end class LongValue < Field; end class DoubleValue < Field; end class StringValue < Field; end class BlobValue < Field; end class ArrayValue < Field; end class Unknown < Field; end end |
#boolean_value ⇒ Boolean
A value of Boolean data type.
664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 |
# File 'lib/aws-sdk-rdsdataservice/types.rb', line 664 class Field < Struct.new( :is_null, :boolean_value, :long_value, :double_value, :string_value, :blob_value, :array_value, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class IsNull < Field; end class BooleanValue < Field; end class LongValue < Field; end class DoubleValue < Field; end class StringValue < Field; end class BlobValue < Field; end class ArrayValue < Field; end class Unknown < Field; end end |
#boolean_values ⇒ Array<Boolean>
An array of Boolean values. Can contain null values.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/aws-sdk-rdsdataservice/types.rb', line 54 class ArrayValue < Struct.new( :boolean_values, :long_values, :double_values, :string_values, :array_values, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class BooleanValues < ArrayValue; end class LongValues < ArrayValue; end class DoubleValues < ArrayValue; end class StringValues < ArrayValue; end class ArrayValues < ArrayValue; end class Unknown < ArrayValue; end end |
#double_value ⇒ Float
A value for a column of double data type.
664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 |
# File 'lib/aws-sdk-rdsdataservice/types.rb', line 664 class Field < Struct.new( :is_null, :boolean_value, :long_value, :double_value, :string_value, :blob_value, :array_value, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class IsNull < Field; end class BooleanValue < Field; end class LongValue < Field; end class DoubleValue < Field; end class StringValue < Field; end class BlobValue < Field; end class ArrayValue < Field; end class Unknown < Field; end end |
#double_values ⇒ Array<Float>
An array of floating-point numbers. Can contain null values.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/aws-sdk-rdsdataservice/types.rb', line 54 class ArrayValue < Struct.new( :boolean_values, :long_values, :double_values, :string_values, :array_values, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class BooleanValues < ArrayValue; end class LongValues < ArrayValue; end class DoubleValues < ArrayValue; end class StringValues < ArrayValue; end class ArrayValues < ArrayValue; end class Unknown < ArrayValue; end end |
#int_value ⇒ Integer
A value for a column of integer data type.
1134 1135 1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 1147 1148 1149 1150 1151 1152 1153 1154 1155 1156 1157 1158 1159 1160 1161 |
# File 'lib/aws-sdk-rdsdataservice/types.rb', line 1134 class Value < Struct.new( :is_null, :bit_value, :big_int_value, :int_value, :double_value, :real_value, :string_value, :blob_value, :array_values, :struct_value, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class IsNull < Value; end class BitValue < Value; end class BigIntValue < Value; end class IntValue < Value; end class DoubleValue < Value; end class RealValue < Value; end class StringValue < Value; end class BlobValue < Value; end class ArrayValues < Value; end class StructValue < Value; end class Unknown < Value; end end |
#is_null ⇒ Boolean
A NULL value.
664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 |
# File 'lib/aws-sdk-rdsdataservice/types.rb', line 664 class Field < Struct.new( :is_null, :boolean_value, :long_value, :double_value, :string_value, :blob_value, :array_value, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class IsNull < Field; end class BooleanValue < Field; end class LongValue < Field; end class DoubleValue < Field; end class StringValue < Field; end class BlobValue < Field; end class ArrayValue < Field; end class Unknown < Field; end end |
#long_value ⇒ Integer
A value of long data type.
664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 |
# File 'lib/aws-sdk-rdsdataservice/types.rb', line 664 class Field < Struct.new( :is_null, :boolean_value, :long_value, :double_value, :string_value, :blob_value, :array_value, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class IsNull < Field; end class BooleanValue < Field; end class LongValue < Field; end class DoubleValue < Field; end class StringValue < Field; end class BlobValue < Field; end class ArrayValue < Field; end class Unknown < Field; end end |
#long_values ⇒ Array<Integer>
An array of integers. Can contain null values.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/aws-sdk-rdsdataservice/types.rb', line 54 class ArrayValue < Struct.new( :boolean_values, :long_values, :double_values, :string_values, :array_values, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class BooleanValues < ArrayValue; end class LongValues < ArrayValue; end class DoubleValues < ArrayValue; end class StringValues < ArrayValue; end class ArrayValues < ArrayValue; end class Unknown < ArrayValue; end end |
#real_value ⇒ Float
A value for a column of real data type.
1134 1135 1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 1147 1148 1149 1150 1151 1152 1153 1154 1155 1156 1157 1158 1159 1160 1161 |
# File 'lib/aws-sdk-rdsdataservice/types.rb', line 1134 class Value < Struct.new( :is_null, :bit_value, :big_int_value, :int_value, :double_value, :real_value, :string_value, :blob_value, :array_values, :struct_value, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class IsNull < Value; end class BitValue < Value; end class BigIntValue < Value; end class IntValue < Value; end class DoubleValue < Value; end class RealValue < Value; end class StringValue < Value; end class BlobValue < Value; end class ArrayValues < Value; end class StructValue < Value; end class Unknown < Value; end end |
#string_value ⇒ String
A value for a column of string data type.
664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 |
# File 'lib/aws-sdk-rdsdataservice/types.rb', line 664 class Field < Struct.new( :is_null, :boolean_value, :long_value, :double_value, :string_value, :blob_value, :array_value, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class IsNull < Field; end class BooleanValue < Field; end class LongValue < Field; end class DoubleValue < Field; end class StringValue < Field; end class BlobValue < Field; end class ArrayValue < Field; end class Unknown < Field; end end |
#string_values ⇒ Array<String>
An array of strings. Can contain null values.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/aws-sdk-rdsdataservice/types.rb', line 54 class ArrayValue < Struct.new( :boolean_values, :long_values, :double_values, :string_values, :array_values, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class BooleanValues < ArrayValue; end class LongValues < ArrayValue; end class DoubleValues < ArrayValue; end class StringValues < ArrayValue; end class ArrayValues < ArrayValue; end class Unknown < ArrayValue; end end |
#struct_value ⇒ Types::StructValue
A value for a column of STRUCT data type.
1134 1135 1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 1147 1148 1149 1150 1151 1152 1153 1154 1155 1156 1157 1158 1159 1160 1161 |
# File 'lib/aws-sdk-rdsdataservice/types.rb', line 1134 class Value < Struct.new( :is_null, :bit_value, :big_int_value, :int_value, :double_value, :real_value, :string_value, :blob_value, :array_values, :struct_value, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class IsNull < Value; end class BitValue < Value; end class BigIntValue < Value; end class IntValue < Value; end class DoubleValue < Value; end class RealValue < Value; end class StringValue < Value; end class BlobValue < Value; end class ArrayValues < Value; end class StructValue < Value; end class Unknown < Value; end end |