Class: Aws::RDSDataService::Types::ExecuteStatementRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-rdsdataservice/types.rb

Overview

The request parameters represent the input of a request to run a SQL statement against a database.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#continue_after_timeoutBoolean

A value that indicates whether to continue running the statement after the call times out. By default, the statement stops running when the call times out.

For DDL statements, we recommend continuing to run the statement after the call times out. When a DDL statement terminates before it is finished running, it can result in errors and possibly corrupted data structures.

Returns:

  • (Boolean)


558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
# File 'lib/aws-sdk-rdsdataservice/types.rb', line 558

class ExecuteStatementRequest < Struct.new(
  :resource_arn,
  :secret_arn,
  :sql,
  :database,
  :schema,
  :parameters,
  :transaction_id,
  :include_result_metadata,
  :continue_after_timeout,
  :result_set_options,
  :format_records_as)
  SENSITIVE = []
  include Aws::Structure
end

#databaseString

The name of the database.

Returns:

  • (String)


558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
# File 'lib/aws-sdk-rdsdataservice/types.rb', line 558

class ExecuteStatementRequest < Struct.new(
  :resource_arn,
  :secret_arn,
  :sql,
  :database,
  :schema,
  :parameters,
  :transaction_id,
  :include_result_metadata,
  :continue_after_timeout,
  :result_set_options,
  :format_records_as)
  SENSITIVE = []
  include Aws::Structure
end

#format_records_asString

A value that indicates whether to format the result set as a single JSON string. This parameter only applies to SELECT statements and is ignored for other types of statements. Allowed values are NONE and JSON. The default value is NONE. The result is returned in the formattedRecords field.

For usage information about the JSON format for result sets, see Using the Data API in the Amazon Aurora User Guide.

Returns:

  • (String)


558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
# File 'lib/aws-sdk-rdsdataservice/types.rb', line 558

class ExecuteStatementRequest < Struct.new(
  :resource_arn,
  :secret_arn,
  :sql,
  :database,
  :schema,
  :parameters,
  :transaction_id,
  :include_result_metadata,
  :continue_after_timeout,
  :result_set_options,
  :format_records_as)
  SENSITIVE = []
  include Aws::Structure
end

#include_result_metadataBoolean

A value that indicates whether to include metadata in the results.

Returns:

  • (Boolean)


558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
# File 'lib/aws-sdk-rdsdataservice/types.rb', line 558

class ExecuteStatementRequest < Struct.new(
  :resource_arn,
  :secret_arn,
  :sql,
  :database,
  :schema,
  :parameters,
  :transaction_id,
  :include_result_metadata,
  :continue_after_timeout,
  :result_set_options,
  :format_records_as)
  SENSITIVE = []
  include Aws::Structure
end

#parametersArray<Types::SqlParameter>

The parameters for the SQL statement.

Array parameters are not supported.

Returns:



558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
# File 'lib/aws-sdk-rdsdataservice/types.rb', line 558

class ExecuteStatementRequest < Struct.new(
  :resource_arn,
  :secret_arn,
  :sql,
  :database,
  :schema,
  :parameters,
  :transaction_id,
  :include_result_metadata,
  :continue_after_timeout,
  :result_set_options,
  :format_records_as)
  SENSITIVE = []
  include Aws::Structure
end

#resource_arnString

The Amazon Resource Name (ARN) of the Aurora Serverless DB cluster.

Returns:

  • (String)


558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
# File 'lib/aws-sdk-rdsdataservice/types.rb', line 558

class ExecuteStatementRequest < Struct.new(
  :resource_arn,
  :secret_arn,
  :sql,
  :database,
  :schema,
  :parameters,
  :transaction_id,
  :include_result_metadata,
  :continue_after_timeout,
  :result_set_options,
  :format_records_as)
  SENSITIVE = []
  include Aws::Structure
end

#result_set_optionsTypes::ResultSetOptions

Options that control how the result set is returned.



558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
# File 'lib/aws-sdk-rdsdataservice/types.rb', line 558

class ExecuteStatementRequest < Struct.new(
  :resource_arn,
  :secret_arn,
  :sql,
  :database,
  :schema,
  :parameters,
  :transaction_id,
  :include_result_metadata,
  :continue_after_timeout,
  :result_set_options,
  :format_records_as)
  SENSITIVE = []
  include Aws::Structure
end

#schemaString

The name of the database schema.

Currently, the schema parameter isn't supported.

Returns:

  • (String)


558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
# File 'lib/aws-sdk-rdsdataservice/types.rb', line 558

class ExecuteStatementRequest < Struct.new(
  :resource_arn,
  :secret_arn,
  :sql,
  :database,
  :schema,
  :parameters,
  :transaction_id,
  :include_result_metadata,
  :continue_after_timeout,
  :result_set_options,
  :format_records_as)
  SENSITIVE = []
  include Aws::Structure
end

#secret_arnString

The ARN of the secret that enables access to the DB cluster. Enter the database user name and password for the credentials in the secret.

For information about creating the secret, see Create a database secret.

When you use the CLI on Linux to reference a secret created in the RDS console, the ARN might include special characters like rds!cluster. If you enclose the ARN in double quotes, the ! character might trigger a shell expansion error, such as -bash: !cluster: event not found. To avoid this, escape the exclamation mark (\!) in the ARN or enclose the entire ARN in single quotes (') instead of double quotes.

Alternatively, disable shell history expansion by running set +H before you execute the command.

Returns:

  • (String)


558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
# File 'lib/aws-sdk-rdsdataservice/types.rb', line 558

class ExecuteStatementRequest < Struct.new(
  :resource_arn,
  :secret_arn,
  :sql,
  :database,
  :schema,
  :parameters,
  :transaction_id,
  :include_result_metadata,
  :continue_after_timeout,
  :result_set_options,
  :format_records_as)
  SENSITIVE = []
  include Aws::Structure
end

#sqlString

The SQL statement to run.

Returns:

  • (String)


558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
# File 'lib/aws-sdk-rdsdataservice/types.rb', line 558

class ExecuteStatementRequest < Struct.new(
  :resource_arn,
  :secret_arn,
  :sql,
  :database,
  :schema,
  :parameters,
  :transaction_id,
  :include_result_metadata,
  :continue_after_timeout,
  :result_set_options,
  :format_records_as)
  SENSITIVE = []
  include Aws::Structure
end

#transaction_idString

The identifier of a transaction that was started by using the BeginTransaction operation. Specify the transaction ID of the transaction that you want to include the SQL statement in.

If the SQL statement is not part of a transaction, don't set this parameter.

Returns:

  • (String)


558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
# File 'lib/aws-sdk-rdsdataservice/types.rb', line 558

class ExecuteStatementRequest < Struct.new(
  :resource_arn,
  :secret_arn,
  :sql,
  :database,
  :schema,
  :parameters,
  :transaction_id,
  :include_result_metadata,
  :continue_after_timeout,
  :result_set_options,
  :format_records_as)
  SENSITIVE = []
  include Aws::Structure
end