Class: Aws::RDSDataService::Types::ResultSetOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDSDataService::Types::ResultSetOptions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rdsdataservice/types.rb
Overview
Options that control how the result set is returned.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#decimal_return_type ⇒ String
A value that indicates how a field of
DECIMALtype is represented in the response. -
#long_return_type ⇒ String
A value that indicates how a field of
LONGtype is represented.
Instance Attribute Details
#decimal_return_type ⇒ String
A value that indicates how a field of DECIMAL type is represented
in the response. The value of STRING, the default, specifies that
it is converted to a String value. The value of DOUBLE_OR_LONG
specifies that it is converted to a Long value if its scale is 0, or
to a Double value otherwise.
851 852 853 854 855 856 |
# File 'lib/aws-sdk-rdsdataservice/types.rb', line 851 class ResultSetOptions < Struct.new( :decimal_return_type, :long_return_type) SENSITIVE = [] include Aws::Structure end |
#long_return_type ⇒ String
A value that indicates how a field of LONG type is represented.
Allowed values are LONG and STRING. The default is LONG.
Specify STRING if the length or precision of numeric values might
cause truncation or rounding errors.
851 852 853 854 855 856 |
# File 'lib/aws-sdk-rdsdataservice/types.rb', line 851 class ResultSetOptions < Struct.new( :decimal_return_type, :long_return_type) SENSITIVE = [] include Aws::Structure end |