Class: Aws::RDSDataService::Types::ExecuteStatementRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDSDataService::Types::ExecuteStatementRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rdsdataservice/types.rb
Overview
The request parameters represent the input of a request to run a SQL statement against a database.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#continue_after_timeout ⇒ Boolean
A value that indicates whether to continue running the statement after the call times out.
-
#database ⇒ String
The name of the database.
-
#format_records_as ⇒ String
A value that indicates whether to format the result set as a single JSON string.
-
#include_result_metadata ⇒ Boolean
A value that indicates whether to include metadata in the results.
-
#parameters ⇒ Array<Types::SqlParameter>
The parameters for the SQL statement.
-
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the Aurora Serverless DB cluster.
-
#result_set_options ⇒ Types::ResultSetOptions
Options that control how the result set is returned.
-
#schema ⇒ String
The name of the database schema.
-
#secret_arn ⇒ String
The ARN of the secret that enables access to the DB cluster.
-
#sql ⇒ String
The SQL statement to run.
-
#transaction_id ⇒ String
The identifier of a transaction that was started by using the ‘BeginTransaction` operation.
Instance Attribute Details
#continue_after_timeout ⇒ Boolean
A value that indicates whether to continue running the statement after the call times out. By default, the statement stops running when the call times out.
<note markdown=“1”> For DDL statements, we recommend continuing to run the statement after the call times out. When a DDL statement terminates before it is finished running, it can result in errors and possibly corrupted data structures.
</note>
558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 |
# File 'lib/aws-sdk-rdsdataservice/types.rb', line 558 class ExecuteStatementRequest < Struct.new( :resource_arn, :secret_arn, :sql, :database, :schema, :parameters, :transaction_id, :include_result_metadata, :continue_after_timeout, :result_set_options, :format_records_as) SENSITIVE = [] include Aws::Structure end |
#database ⇒ String
The name of the database.
558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 |
# File 'lib/aws-sdk-rdsdataservice/types.rb', line 558 class ExecuteStatementRequest < Struct.new( :resource_arn, :secret_arn, :sql, :database, :schema, :parameters, :transaction_id, :include_result_metadata, :continue_after_timeout, :result_set_options, :format_records_as) SENSITIVE = [] include Aws::Structure end |
#format_records_as ⇒ String
A value that indicates whether to format the result set as a single JSON string. This parameter only applies to ‘SELECT` statements and is ignored for other types of statements. Allowed values are `NONE` and `JSON`. The default value is `NONE`. The result is returned in the `formattedRecords` field.
For usage information about the JSON format for result sets, see
- Using the Data API][1
-
in the *Amazon Aurora User Guide*.
[1]: docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/data-api.html
558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 |
# File 'lib/aws-sdk-rdsdataservice/types.rb', line 558 class ExecuteStatementRequest < Struct.new( :resource_arn, :secret_arn, :sql, :database, :schema, :parameters, :transaction_id, :include_result_metadata, :continue_after_timeout, :result_set_options, :format_records_as) SENSITIVE = [] include Aws::Structure end |
#include_result_metadata ⇒ Boolean
A value that indicates whether to include metadata in the results.
558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 |
# File 'lib/aws-sdk-rdsdataservice/types.rb', line 558 class ExecuteStatementRequest < Struct.new( :resource_arn, :secret_arn, :sql, :database, :schema, :parameters, :transaction_id, :include_result_metadata, :continue_after_timeout, :result_set_options, :format_records_as) SENSITIVE = [] include Aws::Structure end |
#parameters ⇒ Array<Types::SqlParameter>
The parameters for the SQL statement.
<note markdown=“1”> Array parameters are not supported.
</note>
558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 |
# File 'lib/aws-sdk-rdsdataservice/types.rb', line 558 class ExecuteStatementRequest < Struct.new( :resource_arn, :secret_arn, :sql, :database, :schema, :parameters, :transaction_id, :include_result_metadata, :continue_after_timeout, :result_set_options, :format_records_as) SENSITIVE = [] include Aws::Structure end |
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the Aurora Serverless DB cluster.
558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 |
# File 'lib/aws-sdk-rdsdataservice/types.rb', line 558 class ExecuteStatementRequest < Struct.new( :resource_arn, :secret_arn, :sql, :database, :schema, :parameters, :transaction_id, :include_result_metadata, :continue_after_timeout, :result_set_options, :format_records_as) SENSITIVE = [] include Aws::Structure end |
#result_set_options ⇒ Types::ResultSetOptions
Options that control how the result set is returned.
558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 |
# File 'lib/aws-sdk-rdsdataservice/types.rb', line 558 class ExecuteStatementRequest < Struct.new( :resource_arn, :secret_arn, :sql, :database, :schema, :parameters, :transaction_id, :include_result_metadata, :continue_after_timeout, :result_set_options, :format_records_as) SENSITIVE = [] include Aws::Structure end |
#schema ⇒ String
The name of the database schema.
<note markdown=“1”> Currently, the ‘schema` parameter isn’t supported.
</note>
558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 |
# File 'lib/aws-sdk-rdsdataservice/types.rb', line 558 class ExecuteStatementRequest < Struct.new( :resource_arn, :secret_arn, :sql, :database, :schema, :parameters, :transaction_id, :include_result_metadata, :continue_after_timeout, :result_set_options, :format_records_as) SENSITIVE = [] include Aws::Structure end |
#secret_arn ⇒ String
The ARN of the secret that enables access to the DB cluster. Enter the database user name and password for the credentials in the secret.
For information about creating the secret, see [Create a database secret].
<note markdown=“1”> When you use the CLI on Linux to reference a secret created in the RDS console, the ARN might include special characters like ‘rds!cluster`. If you enclose the ARN in double quotes, the `!` character might trigger a shell expansion error, such as `-bash: !cluster: event not found`. To avoid this, escape the exclamation mark (\!) in the ARN or enclose the entire ARN in single quotes (’) instead of double quotes.
Alternatively, disable shell history expansion by running `set +H`
before you execute the command.
</note>
[1]: docs.aws.amazon.com/secretsmanager/latest/userguide/create_database_secret.html
558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 |
# File 'lib/aws-sdk-rdsdataservice/types.rb', line 558 class ExecuteStatementRequest < Struct.new( :resource_arn, :secret_arn, :sql, :database, :schema, :parameters, :transaction_id, :include_result_metadata, :continue_after_timeout, :result_set_options, :format_records_as) SENSITIVE = [] include Aws::Structure end |
#sql ⇒ String
The SQL statement to run.
558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 |
# File 'lib/aws-sdk-rdsdataservice/types.rb', line 558 class ExecuteStatementRequest < Struct.new( :resource_arn, :secret_arn, :sql, :database, :schema, :parameters, :transaction_id, :include_result_metadata, :continue_after_timeout, :result_set_options, :format_records_as) SENSITIVE = [] include Aws::Structure end |
#transaction_id ⇒ String
The identifier of a transaction that was started by using the ‘BeginTransaction` operation. Specify the transaction ID of the transaction that you want to include the SQL statement in.
If the SQL statement is not part of a transaction, don’t set this parameter.
558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 |
# File 'lib/aws-sdk-rdsdataservice/types.rb', line 558 class ExecuteStatementRequest < Struct.new( :resource_arn, :secret_arn, :sql, :database, :schema, :parameters, :transaction_id, :include_result_metadata, :continue_after_timeout, :result_set_options, :format_records_as) SENSITIVE = [] include Aws::Structure end |